@@ -1,5 +1,7 @@
 import abc
 
+from six import string_types
+
 
 class FieldFactory(object):
     """
@@ -9,20 +11,22 @@ class FieldFactory(object):
     def __new__(cls, field, *args, **kwargs):
         """
         Determines which type of field class to instantiate based on the field argument
-        @param field: The field used in determining which type of Field object to return.
+        
+        :param field: The field used in determining which type of Field object to return.
             This can be a string of the field name, a dict of {'alias': field},
             or a ``Field``
-        @type table: str or dict or Field
-        @return: The Field instance if a valid type was determined, otherwise None
-        @rtype: Field or None
+        :type table: str or dict or :class:`querybuilder.fields.Field`
+        
+        :return: The Field instance if a valid type was determined, otherwise None
+        :rtype: :class:`querybuilder.fields.Field` or None
         """
         field_type = type(field)
         if field_type is dict:
-            kwargs.update(alias=field.keys()[0])
-            field = field.values()[0]
+            kwargs.update(alias=list(field.keys())[0])
+            field = list(field.values())[0]
             field_type = type(field)
 
-        if field_type is str or field_type is unicode:
+        if isinstance(field, string_types):
             return SimpleField(field, **kwargs)
         elif isinstance(field, Field):
             for key, value in kwargs.items():
@@ -60,17 +64,22 @@ class Field(object):
 
     def __init__(self, field=None, table=None, alias=None, cast=None, distinct=None):
         """
-        @param field: A string of a field name
-        @type field: str
-        @param table: A Table instance used to disambiguate the field. This is optional in
+        
+        :param field: A string of a field name
+        :type field: str
+        
+        :param table: A Table instance used to disambiguate the field. This is optional in
             simple queries
-        @type table: Table
-        @param alias: An alias to be used for this field
-        @type alias: str
-        @param cast: A data type name this field should be cast to. Ex: 'float'
-        @type cast: str
-        @param distinct: Indicates if a DISTINCT flag should be added during sql generation
-        @type cast: bool
+        :type table: :class:`querybuilder.tables.Table`
+        
+        :param alias: An alias to be used for this field
+        :type alias: str
+        
+        :param cast: A data type name this field should be cast to. Ex: 'float'
+        :type cast: str
+        
+        :param distinct: Indicates if a DISTINCT flag should be added during sql generation
+        :type cast: bool
         """
         # TODO: implement distinct
         self.field = field
@@ -87,8 +96,9 @@ class Field(object):
         """
         Gets the SELECT sql part for a field
         Ex: field_name AS alias
-        @return: the sql for this field used in the SELECT portion of the query
-        @rtype: str
+        
+        :return: the sql for this field used in the SELECT portion of the query
+        :rtype: str
         """
         alias = self.get_alias()
         if alias:
@@ -104,8 +114,9 @@ class Field(object):
         """
         Gets the name for the field and returns it. This identifies the field if there
         is not an alias set.
-        @return: The name for the field
-        @rtype: str
+        
+        :return: The name for the field
+        :rtype: str
         """
         alias = self.get_alias()
         if alias:
@@ -116,8 +127,9 @@ class Field(object):
         """
         Gets the alias for the field or the auto_alias if one is set.
         If there isn't any kind of alias, None is returned.
-        @return: The field alias, auto_alias, or None
-        @rtype: str or None
+        
+        :return: The field alias, auto_alias, or None
+        :rtype: str or None
         """
         alias = None
         if self.alias:
@@ -139,8 +151,9 @@ class Field(object):
         Gets the name for the field of how it should
         be referenced within a query. It will be
         prefixed with the table name or table alias
-        @return: the name to reference the field within a query
-        @rtype: str
+        
+        :return: the name to reference the field within a query
+        :rtype: str
         """
         alias = self.get_alias()
         if alias:
@@ -151,8 +164,9 @@ class Field(object):
         """
         Gets the SELECT field portion for the field without the alias. If the field
         has a table, it will be included here like table.field
-        @return: Gets the SELECT field portion for the field without the alias
-        @rtype: str
+        
+        :return: Gets the SELECT field portion for the field without the alias
+        :rtype: str
         """
         if self.table:
             return '{0}.{1}'.format(self.table.get_identifier(), self.name)
@@ -182,17 +196,22 @@ class SimpleField(Field):
     def __init__(self, field=None, table=None, alias=None, cast=None, distinct=None):
         """
         Sets the name of the field to the passed in field value
-        @param field: A string of a field name
-        @type field: str
-        @param table: A Table instance used to disambiguate the field. This is optional in
+        
+        :param field: A string of a field name
+        :type field: str
+        
+        :param table: A Table instance used to disambiguate the field. This is optional in
             simple queries
-        @type table: Table
-        @param alias: An alias to be used for this field
-        @type alias: str
-        @param cast: A data type name this field should be cast to. Ex: 'float'
-        @type cast: str
-        @param distinct: Indicates if a DISTINCT flag should be added during sql generation
-        @type cast: bool
+        :type table: :class:`querybuilder.tables.Table`
+        
+        :param alias: An alias to be used for this field
+        :type alias: str
+        
+        :param cast: A data type name this field should be cast to. Ex: 'float'
+        :type cast: str
+        
+        :param distinct: Indicates if a DISTINCT flag should be added during sql generation
+        :type cast: bool
         """
         super(SimpleField, self).__init__(field, table, alias, cast, distinct)
         self.name = field
@@ -239,26 +258,32 @@ class AggregateField(MultiField):
         """
         Sets the field to a field instance because aggregate functions are treated as fields
         that perform an operation on a db column
-        @param field: A string of a field name
-        @type field: str
-        @param table: A Table instance used to disambiguate the field. This is optional in
+        
+        :param field: A string of a field name
+        :type field: str
+        
+        :param table: A Table instance used to disambiguate the field. This is optional in
             simple queries
-        @type table: Table
-        @param alias: An alias to be used for this field
-        @type alias: str
-        @param cast: A data type name this field should be cast to. Ex: 'float'
-        @type cast: str
-        @param distinct: Indicates if a DISTINCT flag should be added during sql generation
-        @type cast: bool
-        @param over: The QueryWindow to perform the aggregate function over
-        @type over: QueryWindow
+        :type table: :class:`querybuilder.tables.Table`
+        
+        :param alias: An alias to be used for this field
+        :type alias: str
+        
+        :param cast: A data type name this field should be cast to. Ex: 'float'
+        :type cast: str
+        
+        :param distinct: Indicates if a DISTINCT flag should be added during sql generation
+        :type cast: bool
+        
+        :param over: The QueryWindow to perform the aggregate function over
+        :type over: :class:`querybuilder.query.QueryWindow`
         """
         super(AggregateField, self).__init__(field, table, alias, cast, distinct)
         self.name = self.function_name
         self.over = over
 
         field_name = None
-        if self.field and (type(self.field.field) is str or type(self.field.field) is unicode):
+        if self.field and isinstance(self.field.field, string_types):
             field_name = self.field.field
             if field_name == '*':
                 field_name = 'all'
@@ -272,8 +297,9 @@ class AggregateField(MultiField):
         """
         Gets the SELECT field portion for the field without the alias. If the field
         has a table, it will be included here like AggregateFunction(table.field)
-        @return: Gets the SELECT field portion for the field without the alias
-        @rtype: str
+        
+        :return: Gets the SELECT field portion for the field without the alias
+        :rtype: str
         """
         return '{0}({1}){2}'.format(
             self.name.upper(),
@@ -284,16 +310,18 @@ class AggregateField(MultiField):
     def get_field_identifier(self):
         """
         Gets the identifier of the field used in the aggregate function
-        @return: the identifier of the field used in the aggregate function
-        @rtype: str
+        
+        :return: the identifier of the field used in the aggregate function
+        :rtype: str
         """
         return self.field.get_identifier()
 
     def get_over(self):
         """
         Gets the over clause to be used in the window function sql
-        @returns: the over clause to be used in the window function sql
-        @rtype: str
+        
+        :returns: the over clause to be used in the window function sql
+        :rtype: str
         """
         if self.over:
             return ' {0}'.format(self.over.get_sql())
@@ -426,21 +454,28 @@ class NTileField(AggregateField):
     def __init__(self, field=None, table=None, alias=None, cast=None, distinct=None, over=None, num_buckets=1):
         """
         Sets the num_buckets for ntile
-        @param field: A string of a field name
-        @type field: str
-        @param table: A Table instance used to disambiguate the field. This is optional in
+        
+        :param field: A string of a field name
+        :type field: str
+        
+        :param table: A Table instance used to disambiguate the field. This is optional in
             simple queries
-        @type table: Table
-        @param alias: An alias to be used for this field
-        @type alias: str
-        @param cast: A data type name this field should be cast to. Ex: 'float'
-        @type cast: str
-        @param distinct: Indicates if a DISTINCT flag should be added during sql generation
-        @type cast: bool
-        @param over: The QueryWindow to perform the aggregate function over
-        @type over: QueryWindow
-        @param num_buckets: Number of buckets to use for ntile
-        @type num_buckets: int
+        :type table: :class:`querybuilder.tables.Table`
+        
+        :param alias: An alias to be used for this field
+        :type alias: str
+        
+        :param cast: A data type name this field should be cast to. Ex: 'float'
+        :type cast: str
+        
+        :param distinct: Indicates if a DISTINCT flag should be added during sql generation
+        :type cast: bool
+        
+        :param over: The QueryWindow to perform the aggregate function over
+        :type over: :class:`querybuilder.query.QueryWindow`
+
+        :param num_buckets: Number of buckets to use for ntile
+        :type num_buckets: int
         """
         super(NTileField, self).__init__(field, table, alias, cast, distinct, over)
         self.num_buckets = num_buckets
@@ -448,8 +483,9 @@ class NTileField(AggregateField):
     def get_field_identifier(self):
         """
         Returns the number of buckets
-        @return: the number of buckets used for the ntile function
-        @rtype: int
+        
+        :return: the number of buckets used for the ntile function
+        :rtype: int
         """
         return self.num_buckets
 
@@ -462,23 +498,31 @@ class LeadLagField(AggregateField):
     def __init__(self, field=None, table=None, alias=None, cast=None, distinct=None, over=None, offset=1, default=None):
         """
         Sets the offset and default value for the lag/lead calculation
-        @param field: A string of a field name
-        @type field: str
-        @param table: A Table instance used to disambiguate the field. This is optional in
+        
+        :param field: A string of a field name
+        :type field: str
+        
+        :param table: A Table instance used to disambiguate the field. This is optional in
             simple queries
-        @type table: Table
-        @param alias: An alias to be used for this field
-        @type alias: str
-        @param cast: A data type name this field should be cast to. Ex: 'float'
-        @type cast: str
-        @param distinct: Indicates if a DISTINCT flag should be added during sql generation
-        @type cast: bool
-        @param over: The QueryWindow to perform the aggregate function over
-        @type over: QueryWindow
-        @param offset: The offset number of rows which to calculate the lag/lead
-        @type offset: int
-        @param default: The default value to use if the offset doesn't find a field
-        @type default: number or str or object
+        :type table: :class:`querybuilder.tables.Table`
+        
+        :param alias: An alias to be used for this field
+        :type alias: str
+        
+        :param cast: A data type name this field should be cast to. Ex: 'float'
+        :type cast: str
+        
+        :param distinct: Indicates if a DISTINCT flag should be added during sql generation
+        :type cast: bool
+        
+        :param over: The QueryWindow to perform the aggregate function over
+        :type over: :class:`querybuilder.query.QueryWindow`
+        
+        :param offset: The offset number of rows which to calculate the lag/lead
+        :type offset: int
+        
+        :param default: The default value to use if the offset doesn't find a field
+        :type default: number or str or object
         """
         super(LeadLagField, self).__init__(field, table, alias, cast, distinct, over)
         self.offset = offset
@@ -560,21 +604,28 @@ class NthValueField(AggregateField):
     def __init__(self, field=None, table=None, alias=None, cast=None, distinct=None, over=None, n=1):
         """
         Sets the Nth value
-        @param field: A string of a field name
-        @type field: str
-        @param table: A Table instance used to disambiguate the field. This is optional in
+        
+        :param field: A string of a field name
+        :type field: str
+        
+        :param table: A Table instance used to disambiguate the field. This is optional in
             simple queries
-        @type table: Table
-        @param alias: An alias to be used for this field
-        @type alias: str
-        @param cast: A data type name this field should be cast to. Ex: 'float'
-        @type cast: str
-        @param distinct: Indicates if a DISTINCT flag should be added during sql generation
-        @type cast: bool
-        @param over: The QueryWindow to perform the aggregate function over
-        @type over: QueryWindow
-        @param n: the n value to use for the Nth value function
-        @type n: int
+        :type table: :class:`querybuilder.tables.Table`
+        
+        :param alias: An alias to be used for this field
+        :type alias: str
+        
+        :param cast: A data type name this field should be cast to. Ex: 'float'
+        :type cast: str
+        
+        :param distinct: Indicates if a DISTINCT flag should be added during sql generation
+        :type cast: bool
+        
+        :param over: The QueryWindow to perform the aggregate function over
+        :type over: :class:`querybuilder.query.QueryWindow`
+        
+        :param n: the n value to use for the Nth value function
+        :type n: int
         """
         super(NthValueField, self).__init__(field, table, alias, cast, distinct, over)
         self.n = n
@@ -582,8 +633,9 @@ class NthValueField(AggregateField):
     def get_field_identifier(self):
         """
         Returns the field's sql and the n value
-        @return: the field's sql and the n value
-        @rtype: str
+        
+        :return: the field's sql and the n value
+        :rtype: str
         """
         return '{0}, {1}'.format(self.field.get_select_sql(), self.n)
 
@@ -592,7 +644,7 @@ class DatePartField(MultiField):
     """
     Base class for all date part fields
 
-    Proeprties:
+    Properties:
 
         group_name: str
             The name of the date part
@@ -602,26 +654,33 @@ class DatePartField(MultiField):
     def __init__(self, field=None, table=None, alias=None, cast=None, distinct=None, auto=False, desc=False,
                  include_datetime=False):
         """
-        @param field: A string of a field name
-        @type field: str
-        @param table: A Table instance used to disambiguate the field. This is optional in
+        :param field: A string of a field name
+        :type field: str
+        
+        :param table: A Table instance used to disambiguate the field. This is optional in
             simple queries
-        @type table: Table
-        @param alias: An alias to be used for this field
-        @type alias: str
-        @param cast: A data type name this field should be cast to. Ex: 'float'
-        @type cast: str
-        @param distinct: Indicates if a DISTINCT flag should be added during sql generation
-        @type cast: bool
-        @param auto: Set to True for this date field to auto generate the necessary other date parts and
+        :type table: :class:`querybuilder.tables.Table`
+        
+        :param alias: An alias to be used for this field
+        :type alias: str
+        
+        :param cast: A data type name this field should be cast to. Ex: 'float'
+        :type cast: str
+        
+        :param distinct: Indicates if a DISTINCT flag should be added during sql generation
+        :type cast: bool
+        
+        :param auto: Set to True for this date field to auto generate the necessary other date parts and
             apply the appropriate groupings. Defaults to False
-        @type auto: bool
-        @param desc: If this is set to True, the results will be sorted by the datetime field in
+        :type auto: bool
+        
+        :param desc: If this is set to True, the results will be sorted by the datetime field in
             descending order. Defaults to False
-        @type desc: bool
-        @param include_datetime: If set to True, datetime objects will be returned in addition to the
+        :type desc: bool
+        
+        :param include_datetime: If set to True, datetime objects will be returned in addition to the
             unix timestamp. Defaults to False.
-        @type include_datetime: bool
+        :type include_datetime: bool
         """
         super(DatePartField, self).__init__(field, table, alias, cast, distinct)
         self.name = self.group_name
@@ -637,8 +696,9 @@ class DatePartField(MultiField):
     def get_select_sql(self):
         """
         Extract the date part from the date field
-        @return: The EXTRACT sql portion for this field
-        @rtype: str
+        
+        :return: The EXTRACT sql portion for this field
+        :rtype: str
         """
         return 'EXTRACT({0} FROM {1})'.format(self.name, self.field.get_select_sql())
 
@@ -703,12 +763,15 @@ class DatePartField(MultiField):
     def add_to_table(self, field, alias, add_group=False):
         """
         Adds this field to the field's table and optionally group by it
-        @param field: The field to add to the table
-        @type field: str or Field
-        @param alias: The alias for the field
-        @type alias: str
-        @param add_group: Whether or not the table should group by this field
-        @type: bool
+        
+        :param field: The field to add to the table
+        :type field: str or :class:`querybuilder.fields.Field`
+        
+        :param alias: The alias for the field
+        :type alias: str
+        
+        :param add_group: Whether or not the table should group by this field
+        :type: bool
         """
         self.table.add_field({
             alias: field
